@@ -11,6 +11,8 @@ module Graphics.Gloss.Data.Picture
         , arc,    thickArc
         , text
         , bitmap
+        , bitmapSection
+        -- , bitmap
         , color
         , translate, rotate, scale
         , pictures
@@ -55,7 +57,7 @@ circle  = Circle
 thickCircle  :: Float -> Float -> Picture
 thickCircle = ThickCircle
 
--- | A circular arc drawn counter-clockwise between two angles (in degrees) 
+-- | A circular arc drawn counter-clockwise between two angles (in degrees)
 --   at the given radius.
 arc     :: Float -> Float -> Float -> Picture
 arc = Arc
@@ -70,16 +72,15 @@ thickArc = ThickArc
 text :: String -> Picture
 text = Text
 
--- | A bitmap image with a width, height and a Vector holding the 
---   32-bit RGBA bitmap data.
--- 
---  The boolean flag controls whether Gloss should cache the data
---  between frames for speed.
---  If you are programatically generating the image for
---  each frame then use `False`.  
---  If you have loaded it from a file then use `True`.
-bitmap  :: Int -> Int -> BitmapData -> Bool -> Picture
-bitmap = Bitmap
+-- | A bitmap image
+bitmap  :: BitmapData -> Picture
+bitmap bitmapData = Bitmap bitmapData
+
+-- | a subsection of a bitmap image
+--   first argument selects a sub section in the bitmap
+--   second argument determines the bitmap data
+bitmapSection  :: Rectangle -> BitmapData -> Picture
+bitmapSection = BitmapSection
 
 -- | A picture drawn with this color.
 color :: Color -> Picture -> Picture
@@ -112,29 +113,29 @@ lineLoop (x:xs) = Line ((x:xs) ++ [x])
 -- Circles and Arcs -----------------------------------------------------------
 -- | A solid circle with the given radius.
 circleSolid :: Float -> Picture
-circleSolid r 
+circleSolid r
         = thickCircle (r/2) r
 
 
 -- | A solid arc, drawn counter-clockwise between two angles at the given radius.
 arcSolid  :: Float -> Float -> Float -> Picture
-arcSolid a1 a2 r 
-        = thickArc a1 a2 (r/2) r 
+arcSolid a1 a2 r
+        = thickArc a1 a2 (r/2) r
 
 
--- | A wireframe sector of a circle. 
+-- | A wireframe sector of a circle.
 --   An arc is draw counter-clockwise from the first to the second angle at
 --   the given radius. Lines are drawn from the origin to the ends of the arc.
 ---
 --   NOTE: We take the absolute value of the radius incase it's negative.
---   It would also make sense to draw the sector flipped around the 
+--   It would also make sense to draw the sector flipped around the
 --   origin, but I think taking the absolute value will be less surprising
 --   for the user.
--- 
+--
 sectorWire :: Float -> Float -> Float -> Picture
 sectorWire a1 a2 r_
  = let r        = abs r_
-   in  Pictures 
+   in  Pictures
         [ Arc a1 a2 r
         , Line [(0, 0), (r * cos (degToRad a1), r * sin (degToRad a1))]
         , Line [(0, 0), (r * cos (degToRad a2), r * sin (degToRad a2))] ]
@@ -145,11 +146,11 @@ sectorWire a1 a2 r_
 --       arguments to reduce the amount of noise in the extracted docs.
 
 -- | A path representing a rectangle centered about the origin
-rectanglePath 
+rectanglePath
         :: Float        -- ^ width of rectangle
         -> Float        -- ^ height of rectangle
         -> Path
-rectanglePath sizeX sizeY                       
+rectanglePath sizeX sizeY
  = let  sx      = sizeX / 2
         sy      = sizeY / 2
    in   [(-sx, -sy), (-sx, sy), (sx, sy), (sx, -sy)]
